package cn.iocoder.yudao.module.delivery.controller.admin;

import cn.iocoder.yudao.framework.apollo.core.event.Customer.ReceiveCustomerCalTypeEvent;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.module.delivery.entity.EcwVz;
import cn.iocoder.yudao.module.delivery.entity.EcwVzPageReq;
import cn.iocoder.yudao.module.delivery.entity.deptex.zTest;
import cn.iocoder.yudao.module.delivery.listener.TestEvent;
import cn.iocoder.yudao.module.delivery.service.EcwVzService;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.delivery.service.OrderServiceExt;
import cn.iocoder.yudao.module.delivery.service.ZTestService;
import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.service.order.OrderService;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import javax.validation.*;

import io.swagger.v3.oas.annotations.Operation;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * V值转换配置参数(EcwVz)表控制层
 * https://ft0n6y6ben.feishu.cn/sheets/Y7PosKYx5h2O2btS6Gcc0TS7nZe?from=from_copylink
 * @author
 * @since 2024-04-02
 * CNG244324  测试提单号
 */
@RestController
@RequestMapping("/ecwVz/vz")
public class EcwVzController {
    /**
     * 服务对象
     */
    @Resource
    private EcwVzService ecwVzService;

    @Resource
    private ZTestService zTestService;

    @Autowired
    private OrderService orderService;

    @Resource
    private OrderServiceExt orderServiceExt;

    @Resource
    private ApplicationContext applicationContext;


    private final String HYPG = "海运拼柜";
    private final String ZXKY = "专线空运";



    /**
     * 新增数据
     *
     * @param ecwVz 实体
     * @return 新增结果
     */
    @PostMapping("/create")
    public CommonResult<Long> create(@Valid @RequestBody EcwVz ecwVz) {
        System.out.println(ecwVz);
        EcwVz temp = ecwVzService.getOne(new LambdaQueryWrapperX<EcwVz>()
                .eqIfPresent(EcwVz::getTitleZh, ecwVz.getTitleZh()));

        if (temp == null) {
            return success(ecwVzService.create(ecwVz));
        } else {
            ecwVz.setId(temp.getId());
            ecwVzService.update(ecwVz);
            return success(ecwVz.getId());
        }
    }

    /**
     * 编辑数据
     *
     * @param ecwVz 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public CommonResult<Boolean> update(@RequestBody EcwVz ecwVz) {
        //System.out.println(ecwVz);
        ecwVzService.update(ecwVz);
        return success(true);
    }


    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */

    @GetMapping("/delete")
    public CommonResult<Boolean> delete(@RequestParam Long id) {
        //自定义物理删除方法
        ecwVzService.delete(id);
        return success(true);
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/get")
    public CommonResult<EcwVz> getModel(@RequestParam("id") Long id) {
        EcwVz ecwVz = ecwVzService.getModel(id);
        return success(ecwVz);
    }

    /**
     * 查询所有数据
     *
     * @return 实例对象集合
     */
    @GetMapping
    public CommonResult queryAll() {
        return success(this.ecwVzService.list());
    }

    /**
     * 分页查询
     *
     * @return 分页对象集合
     */

    @GetMapping("/page")
    @Operation(summary = "获取分页查询列表")
    public CommonResult<PageResult<EcwVz>> selectPage(@Valid EcwVzPageReq PageReq) {
        return success(this.ecwVzService.selectPage(PageReq));
    }

    @GetMapping("/Test")
    @Operation(summary = "测试功能")
    public CommonResult<Boolean> Test() {

        /*
        TestEvent even = new TestEvent();
        even.setName("测试事件监听");
        applicationContext.publishEvent(even);
         */


        zTest m = new zTest();

        orderService.UpdateOrderYeJiType((long) 1, 1);

        orderService.UpdateOrderVValue((long) 1, new BigDecimal(101), new Date());

        ReceiveCustomerCalTypeEvent e = new ReceiveCustomerCalTypeEvent();
        e.setCustomerId((long) 49345);
        if (orderServiceExt.IsHavingOrder(e) == 0) {
            m.setTestname("无业绩");
            m.setCreatedate(new Date());
            zTestService.save(m);
        } else {
            m.setTestname("有业绩");
            m.setCreatedate(new Date());
            zTestService.save(m);
        }

        return success(true);
    }

    /*
    JSON 和字符串的相互转换
     */
    private void Test2() {
        EcwVz user1 = new EcwVz();
        EcwVz user2 = new EcwVz();
        //1、List 转 Json
        List<EcwVz> list = new ArrayList<>();
        list.add(user1);
        list.add(user2);
        String listToString = JSON.toJSONString(list);
        System.out.println("--------List转Json--------");
        System.out.println(listToString);

        //4、Json转List
        List<EcwVz> jsonToList = JSONArray.parseArray(listToString, EcwVz.class);
        System.out.println("--------Json转List--------");
        for (int i = 0; i < jsonToList.size(); i++) {
            System.out.println(jsonToList.get(i));
        }

    }

}

